#!/usr/bin/env python
# coding: utf-8

# for use with Modern Wage Dynamics Model
# version 1.0.0
#
# June 2022  
# J M Applegate
#
# contains firm functions, called by main.py
#
import numpy as np

def profit(omega, p, S_M, H_M):
    return p * S_M - omega * H_M

def optimal_hours(S_D, A, gamma, e_hat, S_N, n):
    if S_D >= S_N * n: 
        S_P = S_D
    else:
        S_P = S_N * n
    H = (S_P / A) ** ( 1 / gamma) / e_hat
    return e_hat * H, H, S_P

def produce_supply(A, N, gamma, I):
    s = A * N ** gamma # + I
    return s

def adjust_inventory(S_S, S_M, I):
    if S_M < S_S: 
        I += S_S - S_M
    return I

def update_wage_price(omega, pct, omega_min, p, pi, H_S, H_D, S_S, S_D, omega_scaler, eta):
    omega_new = omega
    if  S_S < S_D:
        if pi > 0: 
            omega_new = omega * (1 + pct)
        else: 
            p = p * (1 + pct)
    elif S_S > S_D:
        if pi > 0:
            p = p * (1 - pct) 
        else:
            omega_new = omega * (1 - pct)
    else: 
        omega_new = omega
    if omega_new >= omega_min:
        omega = omega_new
    else: 
        omega = omega_min
    e_hat = min(eta.predict(omega_scaler.transform([[omega]]))[0], 1)
    return omega, p, e_hat

def update_eta(eta, omega, S_S, H_M, A, gamma, omega_memory, effort_memory, omega_scaler):
    omega_memory = np.append(omega_memory, omega)
    perceived_effort = min(1, (S_S / A) ** (1 / gamma) / (H_M))
    effort_memory = np.append(effort_memory, perceived_effort)
    omega_memory_scaled = omega_scaler.transform(omega_memory.reshape(-1, 1))
    eta.fit(omega_memory_scaled, effort_memory)
    return perceived_effort, omega_memory[1:], effort_memory[1:], eta