#!/usr/bin/env python
# coding: utf-8

# for use with Modern Wage Dynamics Model
# version 1.0.0
#
# June 2022  
# J M Applegate
#
# contains household functions, called by main.py
#
import numpy as np

def determine_effort(omega, d, omega_r, e_min):
    if omega > omega_r + d:
        effort = 1 - (d / (omega - omega_r)) ** .5
    else: 
        effort = e_min
    return effort

#tribute hours will fall between 0 and H_max
def tribute_hours(p, S_N, omega, m, sigma, tau, H_max):
    if S_N > 0:
        hours = (p * S_N - (max(0, m) + tau + sigma)) / omega
    else:
        hours = 0
    return min(max(0, hours), H_max)

def calculate_tau(income, c1, c2, c3, c4):
    if income < c2: return c1 / c2 * income
    if income >= c2 and income <= c3: return c1
    if income >= c3 and income <= c4: return -1 * c1 / (c4 - c3) * income + c1 * c4 / (c4 - c3)
    if income > c4: return 0

def determine_hours(omega_r, beta, alpha, H_max, H_N, omega, tau, m, sigma, p, S_N):
    if omega >= omega_r:
        #H_O + H_N
        if H_N > 0:
            hours = beta * (H_max - H_N) + H_N
        else:
            hours = beta * H_max - alpha / omega * (max(0, m) + tau + sigma - p * S_N)
    else:
        hours = H_N
    return hours

def plan_consumption(S_N, omega, upsilon, p, hours, m, EITC, tau, sigma, c1, c2, c3, c4):
    if hours > 0:
        income = hours * omega
        if EITC: tau = calculate_tau(income, c1, c2, c3, c4)
        S = max(S_N, (income + max(m, 0) + tau + sigma) / p)
    else:
        income, tau = 0, 0
        S = max(S_N, (max(m, 0) + sigma + upsilon) / p)   
    return S, income, tau

def calculate_utility(H_max, H_W, S_C, S_N, alpha, beta):
    return (H_max - H_W) ** alpha * np.maximum(0, S_C - S_N) ** beta

def update_ledger(income, tau, sigma, upsilon, p, s, m):
    expenditure = p * s
    if income >= 0:
        m += income + tau + sigma - expenditure
    else:
        m += sigma + upsilon - expenditure
    return m, expenditure