#!/usr/bin/env python
# coding: utf-8

# for use with Modern Wage Dynamics Model
# version 1.0.0
#
# June 2022  
# J M Applegate
#
# contains initialisation functions, called by main.py
#
import numpy as np

from sklearn.preprocessing import MinMaxScaler
from sklearn.neural_network import MLPRegressor

def create_firm(omega_min, omega_0, p_0):
    I = 0                                   
    pi = 0
    total_pi = 0
    omega = max(omega_min, omega_0)
    p = p_0
    e_hat = 1
    H_D = 0
    S_P = 0
    S_S = 0
    perceived_effort = 0
    return I, pi, total_pi, omega, p, e_hat, H_D, S_P, S_S, perceived_effort

def create_households(n, H_max, d_max, upsilon, rng):
    d = rng.uniform(1, d_max, n)
    alpha = rng.uniform(0, 1, n)
    beta = 1 - alpha
    e = np.zeros(n)
    H_N = np.zeros(n)
    H = np.repeat(H_max / 2, n) #set intial household hours to half of H_max
    omega_r = upsilon / H #reserve wage is based on unemployment benefits, and effective unemployment wage is based on half of max hours.
    H_W = np.empty(n)
    income = np.empty(n)
    m = np.zeros(n)
    #m = np.full(n, 2000)
    S = np.empty(n)
    S_C = np.empty(n)
    income = np.empty(n)
    tau = np.zeros(n)
    U = np.zeros(n)
    expenditure = np.zeros(n)
    return d, alpha, beta, e, H_N, H, omega_r, H_W, income, m, S, S_C, tau, U, expenditure

def effort_vector(omega, d, omega_r): #vectorised version of household effort, ensure omegas don't include < omega_r + d
    return 1 - (d / (omega - omega_r)) ** .5

def initialise_eta(d_init, omega_r_init, omega_max, mu, rng):
    omegas = np.arange(d_init + omega_r_init, omega_max, 1)
    
    #omegas need to be scaled
    omega_scaler = MinMaxScaler().fit(omegas.reshape(-1, 1))
    omegas_scaled = omega_scaler.transform(omegas.reshape(-1, 1))
    
    #omegas_train = rng.choice(omegas_scaled, 100)
    omegas_train = omegas_scaled
    efforts_train = effort_vector(omegas, d_init, omega_r_init)
    # efforts don't need scaling as values are between 0 and 1
    
    # Define simple MPL Regression model. 
    # Setting warm_start to true to use earlier fits in future fits, hence gradual learning.
    eta = MLPRegressor(hidden_layer_sizes = (2), activation='logistic', solver='lbfgs', warm_start = True, 
                       max_iter = 200)
    
    #eta needs to be fitted before one can change the out_activation_ function ???
    eta.fit(omegas_train, efforts_train)
    eta.out_activation_ = 'logistic'
    
    #refit with new output activation
    eta.fit(omegas_train, efforts_train)
    
    #subset omegas and efforts_train using mu to create memory arrays
    indicies = rng.integers(0, len(omegas_train), size = mu)
    omega_memory = omegas[indicies]
    effort_memory = efforts_train[indicies]
    
    return omegas, omegas_scaled, omegas_train, efforts_train, omega_scaler, omega_memory, effort_memory, eta