#!/usr/bin/env python
# coding: utf-8

# for use with Modern Wage Dynamics Model
# version 1.0.0
#
# June 2022
# J M Applegate
#
# used to specify all parameter values, called by main.py
#
def series_params():
    series_name = 'TES_1'
    directory = '../results/'

    # series variables
    #seed = 71205
    seed = None
    #verbose = True
    verbose = False
    t_max = 1200 #500 #number of simulation months
    reps = 12 #repetitions of each parameter set

    # simulation variables
    n_list = [100] #number of households
    omega_0_list = [10] #inital wage
    omega_max = 200 #max hourly wage for eta initialisation
    H_max = 400 #max household hours per month

    # firm parameters
    A_list = [3]
    gamma_list = [1.2] #firm production function
    mu = 20 #memory for firm expectation updates
    pct = .01 #percentage of wage adjustment

    #policy parameters in terms of months
    #EITC
    EITC_list = [0] # EITC flag
    c1 = 500 # 6000 / 12
    c2 = 1250 # 15000 / 12
    c3 = 2500 # 30000 / 12
    c4 = 4583 # 55000 / 12
    #miniumum wage
    omega_min_list = [0] #[0, 7]
    #monthly unemployment benefit
    upsilon_list = [0] #[0, 1000]
    #univeral supplemental income
    sigma_list = [0]

    #base consumption requirement, per month
    S_N_list = [1200] #minimum household consumption
    p_0_list = [1] #intial price

    #maximum value of disutility of labour
    d_max_list = [5]
    e_min = .2

    #combine multi-value parameters
    param_names = ['n', 'omega_0', 'A', 'gamma', 'EITC', 'upsilon', 'omega_min', 'sigma', 'S_N', 'p_0', 'd_max']

    param_sets = [[n, omega_0, A, gamma, EITC, upsilon, omega_min, sigma, S_N, p_0, d_max] for n in n_list for omega_0 in omega_0_list for A in A_list for gamma in gamma_list for EITC in EITC_list for upsilon in upsilon_list for omega_min in omega_min_list for sigma in sigma_list for S_N in S_N_list for p_0 in p_0_list for d_max in d_max_list]

    n_sets = len(param_sets)

    # make parameter dictionary (variable and fixed parameters
    fixed_params = {'t_max': t_max,
                    'omega_max': omega_max,
                    'H_max': H_max,
                    'mu': mu,
                    'pct': pct,
                    'e_min': e_min,
                    'c1': c1,
                    'c2': c2,
                    'c3': c3,
                    'c4': c4
                   }

    sim_params_list = [{**dict(zip(param_names, ps)), **fixed_params} for ps in param_sets]

    return directory, series_name, verbose, seed, n_sets, sim_params_list, reps
